vatman: Vad-Ass Transit Model cAlculatioN
=========================================

The ``batman`` package for Python makes super fast calculation of transit light curves easy.  Check out the docs at https://www.cfa.harvard.edu/~lkreidberg/batman/.

This is a fork of the original `batman-package` to make it installable under the new Python distributions as the original repository is not very active.
